==> apgl-0.5.9.1.tar.gz: apgl-0.5.9.1/apgl/predictors/MlpySVM.py <==
'''
Created on 23 Jul 2009

@author: charanpal

A wrapper for MLPy SVM 
'''

import logging

from apgl.predictors import *
from apgl.util import *

class MlpySVM(AbstractSVMPredictor):
    """
    The parameter cost is implemented essentially as a factor modifying the cost
    of making a misclassification - ranging between -1 and 1, it modifies the svm
    weights on the corresponding labelled class.
    NOTE: For the gaussian kernel, the parameter is the value of 2\sigma^2 !!! 
    """
    def __init__(self, kernel='linear', kp=0.1, C=1.0, cost=0.0):
        Parameter.checkString(kernel, ["linear", "polynomial", "gaussian"])
        Parameter.checkFloat(C, 0.0, float('inf'))
        Parameter.checkFloat(cost, -1.0, 1.0)

        self.tol = 0.001
        self.eps = 0.001
        self.maxloops = 1000
        self.cost = cost
        self.setParams(C, kernel, kp)
    
    def setParams(self, C, kernel, kernelParam):
        Parameter.checkString(kernel, ["linear", "polynomial", "gaussian"])
        Parameter.checkFloat(C, 0.0, float('inf'))

        try:
            import mlpy
        except ImportError:
            print("Must have mlpy installed to use this function.")
            pass 

        self.kernel = kernel
        self.C = C
        if kernel == "gaussian":
            self.kp = 2*kernelParam**2
        else:
            self.kp = kernelParam

        self.svm = mlpy.Svm(self.kernel, self.kp, self.C, self.tol, self.eps, self.maxloops, self.cost)

    def setErrorCost(self, errorCost):
        Parameter.checkFloat(errorCost, -1.0, 1.0)

        try:
            import mlpy
        except ImportError:
            print("Must have mlpy installed to use this function.")
            pass 

        self.cost = errorCost
        self.svm = mlpy.Svm(self.kernel, self.kp, self.C, self.tol, self.eps, self.maxloops, self.cost)

    def learnModel(self, examplesList):
        X, y = examplesList.getSampledExamplesLabels()

        self.svm.compute(X, y)
    
    def classify(self, examplesList):
        """
        Classify a set of examples and return an array of predicted labels
        """
        exName = examplesList.getDefaultExamplesName()
        
        return self.svm.predict(examplesList.getSampledDataField(exName))
        
    svm = 0

==> apgl-0.6.1.tar.gz: apgl-0.6.1/apgl/predictors/MlpySVM.py <==
'''
Created on 23 Jul 2009

@author: charanpal

A wrapper for MLPy SVM 
'''

import logging
import numpy 
from apgl.predictors import *
from apgl.util import *

class MlpySVM(AbstractSVMPredictor):
    """
    The parameter cost is implemented essentially as a factor modifying the cost
    of making a misclassification - ranging between -1 and 1, it modifies the svm
    weights on the corresponding labelled class.
    NOTE: For the gaussian kernel, the parameter is the value of 2\sigma^2 !!! 
    """
    def __init__(self, kernel='linear', kp=0.1, C=1.0, cost=0.0):
        Parameter.checkString(kernel, ["linear", "polynomial", "gaussian"])
        Parameter.checkFloat(C, 0.0, float('inf'))
        Parameter.checkFloat(cost, -1.0, 1.0)

        self.tol = 0.001
        self.eps = 0.001
        self.maxloops = 1000
        self.cost = cost
        self.setParams(C, kernel, kp)
    
    def setParams(self, C, kernel, kernelParam):
        Parameter.checkString(kernel, ["linear", "polynomial", "gaussian"])
        Parameter.checkFloat(C, 0.0, float('inf'))

        try:
            import mlpy
        except ImportError:
            print("Must have mlpy installed to use this function.")
            pass 

        self.kernel = kernel
        self.C = C
        if kernel == "gaussian":
            self.kp = 2*kernelParam**2
        else:
            self.kp = kernelParam

        self.svm = mlpy.Svm(self.kernel, self.kp, self.C, self.tol, self.eps, self.maxloops, self.cost)

    def setErrorCost(self, errorCost):
        Parameter.checkFloat(errorCost, -1.0, 1.0)

        try:
            import mlpy
        except ImportError:
            print("Must have mlpy installed to use this function.")
            pass 

        self.cost = errorCost
        self.svm = mlpy.Svm(self.kernel, self.kp, self.C, self.tol, self.eps, self.maxloops, self.cost)

    def learnModel(self, X, y):
        self.svm.compute(X, y)
    
    def classify(self, X):
        """
        Classify a set of examples and return an array of predicted labels
        """
        Parameter.checkClass(X, numpy.ndarray)
        
        return self.svm.predict(X)
        
    svm = 0
